@@ -16,7 +16,12 @@ import aws_cdk.core._jsii
 import aws_cdk.cx_api._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-cloudformation", "1.46.0", __name__[0:-6], "aws-cloudformation@1.46.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-cloudformation",
+    "1.53.0",
+    __name__[0:-6],
+    "aws-cloudformation@1.53.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
